measuretools.apply_beam_spanners_to_measures_in_expr
====================================================

.. autofunction:: abjad.tools.measuretools.apply_beam_spanners_to_measures_in_expr.apply_beam_spanners_to_measures_in_expr
